@@ -14,7 +14,7 @@ logger = logging.getLogger(__name__)
 
 
 class AMLJobManager:
-    def __init__(self, subscription_id, workspace_name, experiment_name, compute_target_name, use_sp_on_remote=False):
+    def __init__(self, subscription_id, workspace_name, experiment_name, compute_target_name, use_sp_on_remote=False, cache_url=None):
         """
         Args:
             subscription_id (str): The subscription ID for the azureml resource.
@@ -22,11 +22,13 @@ class AMLJobManager:
             experiment_name (str): Experiment name
             compute_target_name (str): Compute Target name
             use_sp_on_remote (bool): If True, get AZURE_TENANT_ID, AZURE_CLIENT_ID, AZURE_CLIENT_SECRET from environment and send it to the AzureML.
-        """
+            cache_url (str): URL to a cache storage. If provided, it will be used in an AzureML job.
+       """
         self._workspace = self._get_workspace(subscription_id, workspace_name)
         self._experiment = azureml.core.Experiment(workspace=self._workspace, name=experiment_name)
         self._compute_target_name = compute_target_name
         self._use_sp_on_remote = use_sp_on_remote
+        self._cache_url = cache_url
 
     def _get_workspace(self, subscription_id, workspace_name):
         auth = None
@@ -70,6 +72,9 @@ class AMLJobManager:
             env_vars['AZURE_CLIENT_ID'] = client_id
             env_vars['AZURE_CLIENT_SECRET'] = client_secret
 
+        if self._cache_url:
+            env_vars['IRISML_CACHE_URL'] = self._cache_url
+
         return env_vars
 
     def get_script_run_config(self, project_dir, job, job_env, environment_variables):
